////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  dsx_1_0_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "dsx_1_0_0.h"
#include "parametersetmanager.h"

DSX_1_0_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_dsx10_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "param_calc_mode") == 0)
    {
        ParameterUtils::DoubleToString((double)param_calc_mode, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_dsx10_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "param_calc_mode") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            param_calc_mode = (UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_dsx10_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // param_calc_mode
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("param_calc_mode", ParameterParserDataType::UInt32, (double)param_calc_mode, 0));
    }
    else if (PARAMETER_STRCMP(__name, "param_calc_mode") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)param_calc_mode, 0));
    }

    return __result;
}

bool dsx10_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_kernel_weights_unpacked_horiz_tab") == 0)
    {
        __result = luma_kernel_weights_unpacked_horiz_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "luma_kernel_weights_unpacked_vert_tab") == 0)
    {
        __result = luma_kernel_weights_unpacked_vert_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_kernel_weights_unpacked_horiz_tab") == 0)
    {
        __result = chroma_kernel_weights_unpacked_horiz_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_kernel_weights_unpacked_vert_tab") == 0)
    {
        __result = chroma_kernel_weights_unpacked_vert_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_en") == 0)
    {
        ParameterUtils::DoubleToString((double)luma_padding_weights_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_en") == 0)
    {
        ParameterUtils::DoubleToString((double)chroma_padding_weights_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_top_tab") == 0)
    {
        __result = luma_padding_weights_top_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_bot_tab") == 0)
    {
        __result = luma_padding_weights_bot_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_left_tab") == 0)
    {
        __result = luma_padding_weights_left_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_right_tab") == 0)
    {
        __result = luma_padding_weights_right_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_top_tab") == 0)
    {
        __result = chroma_padding_weights_top_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_bot_tab") == 0)
    {
        __result = chroma_padding_weights_bot_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_left_tab") == 0)
    {
        __result = chroma_padding_weights_left_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_right_tab") == 0)
    {
        __result = chroma_padding_weights_right_tab.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool dsx10_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_kernel_weights_unpacked_horiz_tab") == 0)
    {
        __result = luma_kernel_weights_unpacked_horiz_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "luma_kernel_weights_unpacked_vert_tab") == 0)
    {
        __result = luma_kernel_weights_unpacked_vert_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_kernel_weights_unpacked_horiz_tab") == 0)
    {
        __result = chroma_kernel_weights_unpacked_horiz_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_kernel_weights_unpacked_vert_tab") == 0)
    {
        __result = chroma_kernel_weights_unpacked_vert_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            luma_padding_weights_en = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            chroma_padding_weights_en = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_top_tab") == 0)
    {
        __result = luma_padding_weights_top_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_bot_tab") == 0)
    {
        __result = luma_padding_weights_bot_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_left_tab") == 0)
    {
        __result = luma_padding_weights_left_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_right_tab") == 0)
    {
        __result = luma_padding_weights_right_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_top_tab") == 0)
    {
        __result = chroma_padding_weights_top_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_bot_tab") == 0)
    {
        __result = chroma_padding_weights_bot_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_left_tab") == 0)
    {
        __result = chroma_padding_weights_left_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_right_tab") == 0)
    {
        __result = chroma_padding_weights_right_tab.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool dsx10_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luma_kernel_weights_unpacked_horiz_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_kernel_weights_unpacked_horiz_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "luma_kernel_weights_unpacked_horiz_tab") == 0)
    {
        __result = luma_kernel_weights_unpacked_horiz_tab.GetInfo(&__path[__pos], __info);
    }

    // luma_kernel_weights_unpacked_vert_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_kernel_weights_unpacked_vert_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "luma_kernel_weights_unpacked_vert_tab") == 0)
    {
        __result = luma_kernel_weights_unpacked_vert_tab.GetInfo(&__path[__pos], __info);
    }

    // chroma_kernel_weights_unpacked_horiz_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_kernel_weights_unpacked_horiz_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chroma_kernel_weights_unpacked_horiz_tab") == 0)
    {
        __result = chroma_kernel_weights_unpacked_horiz_tab.GetInfo(&__path[__pos], __info);
    }

    // chroma_kernel_weights_unpacked_vert_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_kernel_weights_unpacked_vert_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chroma_kernel_weights_unpacked_vert_tab") == 0)
    {
        __result = chroma_kernel_weights_unpacked_vert_tab.GetInfo(&__path[__pos], __info);
    }

    // luma_padding_weights_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_padding_weights_en", ParameterParserDataType::UInt32, (double)luma_padding_weights_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)luma_padding_weights_en, 0));
    }

    // chroma_padding_weights_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_padding_weights_en", ParameterParserDataType::UInt32, (double)chroma_padding_weights_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)chroma_padding_weights_en, 0));
    }

    // luma_padding_weights_top_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_padding_weights_top_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_top_tab") == 0)
    {
        __result = luma_padding_weights_top_tab.GetInfo(&__path[__pos], __info);
    }

    // luma_padding_weights_bot_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_padding_weights_bot_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_bot_tab") == 0)
    {
        __result = luma_padding_weights_bot_tab.GetInfo(&__path[__pos], __info);
    }

    // luma_padding_weights_left_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_padding_weights_left_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_left_tab") == 0)
    {
        __result = luma_padding_weights_left_tab.GetInfo(&__path[__pos], __info);
    }

    // luma_padding_weights_right_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_padding_weights_right_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "luma_padding_weights_right_tab") == 0)
    {
        __result = luma_padding_weights_right_tab.GetInfo(&__path[__pos], __info);
    }

    // chroma_padding_weights_top_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_padding_weights_top_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_top_tab") == 0)
    {
        __result = chroma_padding_weights_top_tab.GetInfo(&__path[__pos], __info);
    }

    // chroma_padding_weights_bot_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_padding_weights_bot_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_bot_tab") == 0)
    {
        __result = chroma_padding_weights_bot_tab.GetInfo(&__path[__pos], __info);
    }

    // chroma_padding_weights_left_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_padding_weights_left_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_left_tab") == 0)
    {
        __result = chroma_padding_weights_left_tab.GetInfo(&__path[__pos], __info);
    }

    // chroma_padding_weights_right_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_padding_weights_right_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chroma_padding_weights_right_tab") == 0)
    {
        __result = chroma_padding_weights_right_tab.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_kernel_weights_unpacked_horiz_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_kernel_weights_unpacked_horiz") == 0)
    {
        if (__index < 192)
        {
            ParameterUtils::DoubleToString((double)luma_kernel_weights_unpacked_horiz[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 192; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)luma_kernel_weights_unpacked_horiz[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_kernel_weights_unpacked_horiz_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_kernel_weights_unpacked_horiz") == 0)
    {
        if (__index < 192)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                luma_kernel_weights_unpacked_horiz[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 192)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    luma_kernel_weights_unpacked_horiz[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_kernel_weights_unpacked_horiz_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luma_kernel_weights_unpacked_horiz
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_kernel_weights_unpacked_horiz", ParameterParserDataType::Int32, true, false, 192));
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_kernel_weights_unpacked_vert_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_kernel_weights_unpacked_vert") == 0)
    {
        if (__index < 192)
        {
            ParameterUtils::DoubleToString((double)luma_kernel_weights_unpacked_vert[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 192; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)luma_kernel_weights_unpacked_vert[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_kernel_weights_unpacked_vert_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_kernel_weights_unpacked_vert") == 0)
    {
        if (__index < 192)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                luma_kernel_weights_unpacked_vert[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 192)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    luma_kernel_weights_unpacked_vert[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_kernel_weights_unpacked_vert_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luma_kernel_weights_unpacked_vert
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_kernel_weights_unpacked_vert", ParameterParserDataType::Int32, true, false, 192));
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_kernel_weights_unpacked_horiz_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_kernel_weights_unpacked_horiz") == 0)
    {
        if (__index < 96)
        {
            ParameterUtils::DoubleToString((double)chroma_kernel_weights_unpacked_horiz[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 96; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)chroma_kernel_weights_unpacked_horiz[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_kernel_weights_unpacked_horiz_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_kernel_weights_unpacked_horiz") == 0)
    {
        if (__index < 96)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                chroma_kernel_weights_unpacked_horiz[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 96)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    chroma_kernel_weights_unpacked_horiz[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_kernel_weights_unpacked_horiz_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // chroma_kernel_weights_unpacked_horiz
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_kernel_weights_unpacked_horiz", ParameterParserDataType::Int32, true, false, 96));
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_kernel_weights_unpacked_vert_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_kernel_weights_unpacked_vert") == 0)
    {
        if (__index < 96)
        {
            ParameterUtils::DoubleToString((double)chroma_kernel_weights_unpacked_vert[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 96; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)chroma_kernel_weights_unpacked_vert[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_kernel_weights_unpacked_vert_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_kernel_weights_unpacked_vert") == 0)
    {
        if (__index < 96)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                chroma_kernel_weights_unpacked_vert[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 96)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    chroma_kernel_weights_unpacked_vert[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_kernel_weights_unpacked_vert_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // chroma_kernel_weights_unpacked_vert
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_kernel_weights_unpacked_vert", ParameterParserDataType::Int32, true, false, 96));
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_top_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_padding_weights_top") == 0)
    {
        if (__index < 24)
        {
            ParameterUtils::DoubleToString((double)luma_padding_weights_top[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 24; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)luma_padding_weights_top[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_top_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_padding_weights_top") == 0)
    {
        if (__index < 24)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                luma_padding_weights_top[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 24)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    luma_padding_weights_top[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_top_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luma_padding_weights_top
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_padding_weights_top", ParameterParserDataType::Int32, true, false, 24));
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_bot_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_padding_weights_bot") == 0)
    {
        if (__index < 24)
        {
            ParameterUtils::DoubleToString((double)luma_padding_weights_bot[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 24; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)luma_padding_weights_bot[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_bot_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_padding_weights_bot") == 0)
    {
        if (__index < 24)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                luma_padding_weights_bot[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 24)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    luma_padding_weights_bot[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_bot_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luma_padding_weights_bot
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_padding_weights_bot", ParameterParserDataType::Int32, true, false, 24));
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_left_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_padding_weights_left") == 0)
    {
        if (__index < 24)
        {
            ParameterUtils::DoubleToString((double)luma_padding_weights_left[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 24; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)luma_padding_weights_left[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_left_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_padding_weights_left") == 0)
    {
        if (__index < 24)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                luma_padding_weights_left[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 24)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    luma_padding_weights_left[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_left_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luma_padding_weights_left
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_padding_weights_left", ParameterParserDataType::Int32, true, false, 24));
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_right_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_padding_weights_right") == 0)
    {
        if (__index < 24)
        {
            ParameterUtils::DoubleToString((double)luma_padding_weights_right[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 24; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)luma_padding_weights_right[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_right_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "luma_padding_weights_right") == 0)
    {
        if (__index < 24)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                luma_padding_weights_right[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 24)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    luma_padding_weights_right[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::luma_padding_weights_right_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // luma_padding_weights_right
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_padding_weights_right", ParameterParserDataType::Int32, true, false, 24));
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_top_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_padding_weights_top") == 0)
    {
        if (__index < 8)
        {
            ParameterUtils::DoubleToString((double)chroma_padding_weights_top[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 8; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)chroma_padding_weights_top[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_top_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_padding_weights_top") == 0)
    {
        if (__index < 8)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                chroma_padding_weights_top[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 8)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    chroma_padding_weights_top[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_top_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // chroma_padding_weights_top
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_padding_weights_top", ParameterParserDataType::Int32, true, false, 8));
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_bot_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_padding_weights_bot") == 0)
    {
        if (__index < 8)
        {
            ParameterUtils::DoubleToString((double)chroma_padding_weights_bot[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 8; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)chroma_padding_weights_bot[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_bot_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_padding_weights_bot") == 0)
    {
        if (__index < 8)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                chroma_padding_weights_bot[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 8)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    chroma_padding_weights_bot[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_bot_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // chroma_padding_weights_bot
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_padding_weights_bot", ParameterParserDataType::Int32, true, false, 8));
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_left_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_padding_weights_left") == 0)
    {
        if (__index < 8)
        {
            ParameterUtils::DoubleToString((double)chroma_padding_weights_left[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 8; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)chroma_padding_weights_left[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_left_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_padding_weights_left") == 0)
    {
        if (__index < 8)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                chroma_padding_weights_left[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 8)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    chroma_padding_weights_left[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_left_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // chroma_padding_weights_left
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_padding_weights_left", ParameterParserDataType::Int32, true, false, 8));
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_right_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_padding_weights_right") == 0)
    {
        if (__index < 8)
        {
            ParameterUtils::DoubleToString((double)chroma_padding_weights_right[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 8; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)chroma_padding_weights_right[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_right_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "chroma_padding_weights_right") == 0)
    {
        if (__index < 8)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                chroma_padding_weights_right[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 8)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    chroma_padding_weights_right[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool dsx10_rgn_dataType::chroma_padding_weights_right_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // chroma_padding_weights_right
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chroma_padding_weights_right", ParameterParserDataType::Int32, true, false, 8));
    }

    return __result;
}

bool mod_dsx10_sr_scale_ratio_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "sr_scale_ratio_trigger") == 0)
    {
        __result = sr_scale_ratio_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "dsx10_rgn_data") == 0)
    {
        __result = dsx10_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_dsx10_sr_scale_ratio_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "sr_scale_ratio_trigger") == 0)
    {
        __result = sr_scale_ratio_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "dsx10_rgn_data") == 0)
    {
        __result = dsx10_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_dsx10_sr_scale_ratio_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // sr_scale_ratio_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("sr_scale_ratio_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "sr_scale_ratio_trigger") == 0)
    {
        __result = sr_scale_ratio_trigger.GetInfo(&__path[__pos], __info);
    }

    // dsx10_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dsx10_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "dsx10_rgn_data") == 0)
    {
        __result = dsx10_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_dsx10_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_dsx10_sr_scale_ratio_data") == 0)
    {
        if (__index < mod_dsx10_sr_scale_ratio_dataCount)
        {
            __result = mod_dsx10_sr_scale_ratio_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_dsx10_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_dsx10_sr_scale_ratio_data") == 0)
    {
        if (__index < mod_dsx10_sr_scale_ratio_dataCount)
        {
            __result = mod_dsx10_sr_scale_ratio_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_dsx10_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_dsx10_sr_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_dsx10_sr_scale_ratio_data", ParameterParserDataType::Structure, true, false, mod_dsx10_sr_scale_ratio_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_dsx10_sr_scale_ratio_data") == 0)
    {
        if (__index < mod_dsx10_sr_scale_ratio_dataCount)
        {
            __result = mod_dsx10_sr_scale_ratio_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_dsx10_sr_scale_ratio_dataCount));
        }
    }

    return __result;
}

bool chromatix_dsx10Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_dsx10_reserve") == 0)
    {
        __result = chromatix_dsx10_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_dsx10_core") == 0)
    {
        __result = chromatix_dsx10_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_dsx10Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_dsx10_reserve") == 0)
    {
        __result = chromatix_dsx10_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_dsx10_core") == 0)
    {
        __result = chromatix_dsx10_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_dsx10Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // chromatix_dsx10_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_dsx10_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_dsx10_reserve") == 0)
    {
        __result = chromatix_dsx10_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_dsx10_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_dsx10_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_dsx10_core") == 0)
    {
        __result = chromatix_dsx10_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_dsx10Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_dsx10Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_dsx10Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_dsx10Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_dsx10Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_dsx10Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_dsx10Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)control_var_type, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_dsx10Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            control_var_type = (control_var_typeEnum)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_dsx10Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, (double)(UINT32)control_var_type, 0));
    }
    else if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)control_var_type, 0));
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_dsx10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_dsx10Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_dsx10Type::control_variablesStruct::control_var_typeEnum::control_sr_scale_ratio):
            enumValue = chromatix_dsx10Type::control_variablesStruct::control_var_typeEnum::control_sr_scale_ratio;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_dsx10Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_dsx10TypeClass::chromatix_dsx10TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(chromatix_dsx10_reserve);
    PARAMETER_INITIALIZE(chromatix_dsx10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_dsx10TypeClass::chromatix_dsx10TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(chromatix_dsx10_reserve);
    PARAMETER_INITIALIZE(chromatix_dsx10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_dsx10TypeClass::~chromatix_dsx10TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_dsx10TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "dsx10_ife_video_full_dc4")) == 0)
    {
        name = "dsx10_ife_video_full_dc4";
    }
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "dsx10_ipe_tf_dc4")) == 0)
    {
        name = "dsx10_ipe_tf_dc4";
    }
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "dsx10_eva_tf_dc4_ld0ds")) == 0)
    {
        name = "dsx10_eva_tf_dc4_ld0ds";
    }
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "dsx10_eva_tf_dc4_mvds")) == 0)
    {
        name = "dsx10_eva_tf_dc4_mvds";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_dsx10_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_dsx10_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(param_calc_mode);

    SYMBOL_TABLE_ENTRY_READ(entry, result, param_calc_mode, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luma_kernel_weights_unpacked_horiz_tab);
    PARAMETER_INITIALIZE(luma_kernel_weights_unpacked_vert_tab);
    PARAMETER_INITIALIZE(chroma_kernel_weights_unpacked_horiz_tab);
    PARAMETER_INITIALIZE(chroma_kernel_weights_unpacked_vert_tab);
    PARAMETER_INITIALIZE(luma_padding_weights_en);
    PARAMETER_INITIALIZE(chroma_padding_weights_en);
    PARAMETER_INITIALIZE(luma_padding_weights_top_tab);
    PARAMETER_INITIALIZE(luma_padding_weights_bot_tab);
    PARAMETER_INITIALIZE(luma_padding_weights_left_tab);
    PARAMETER_INITIALIZE(luma_padding_weights_right_tab);
    PARAMETER_INITIALIZE(chroma_padding_weights_top_tab);
    PARAMETER_INITIALIZE(chroma_padding_weights_bot_tab);
    PARAMETER_INITIALIZE(chroma_padding_weights_left_tab);
    PARAMETER_INITIALIZE(chroma_padding_weights_right_tab);

    result = luma_kernel_weights_unpacked_horiz_tab.Load(entry, alignment);
    if (result)
    {
        result = luma_kernel_weights_unpacked_vert_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = chroma_kernel_weights_unpacked_horiz_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = chroma_kernel_weights_unpacked_vert_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, luma_padding_weights_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, chroma_padding_weights_en, alignment)
    if (result)
    {
        result = luma_padding_weights_top_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = luma_padding_weights_bot_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = luma_padding_weights_left_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = luma_padding_weights_right_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = chroma_padding_weights_top_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = chroma_padding_weights_bot_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = chroma_padding_weights_left_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = chroma_padding_weights_right_tab.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_luma_kernel_weights_unpacked_horiz_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::luma_kernel_weights_unpacked_horiz_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luma_kernel_weights_unpacked_horiz);

    result = entry->ReadArray(luma_kernel_weights_unpacked_horiz, 192, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_luma_kernel_weights_unpacked_vert_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::luma_kernel_weights_unpacked_vert_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luma_kernel_weights_unpacked_vert);

    result = entry->ReadArray(luma_kernel_weights_unpacked_vert, 192, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_chroma_kernel_weights_unpacked_horiz_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::chroma_kernel_weights_unpacked_horiz_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(chroma_kernel_weights_unpacked_horiz);

    result = entry->ReadArray(chroma_kernel_weights_unpacked_horiz, 96, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_chroma_kernel_weights_unpacked_vert_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::chroma_kernel_weights_unpacked_vert_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(chroma_kernel_weights_unpacked_vert);

    result = entry->ReadArray(chroma_kernel_weights_unpacked_vert, 96, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_luma_padding_weights_top_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::luma_padding_weights_top_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luma_padding_weights_top);

    result = entry->ReadArray(luma_padding_weights_top, 24, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_luma_padding_weights_bot_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::luma_padding_weights_bot_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luma_padding_weights_bot);

    result = entry->ReadArray(luma_padding_weights_bot, 24, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_luma_padding_weights_left_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::luma_padding_weights_left_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luma_padding_weights_left);

    result = entry->ReadArray(luma_padding_weights_left, 24, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_luma_padding_weights_right_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::luma_padding_weights_right_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(luma_padding_weights_right);

    result = entry->ReadArray(luma_padding_weights_right, 24, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_chroma_padding_weights_top_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::chroma_padding_weights_top_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(chroma_padding_weights_top);

    result = entry->ReadArray(chroma_padding_weights_top, 8, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_chroma_padding_weights_bot_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::chroma_padding_weights_bot_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(chroma_padding_weights_bot);

    result = entry->ReadArray(chroma_padding_weights_bot, 8, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_chroma_padding_weights_left_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::chroma_padding_weights_left_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(chroma_padding_weights_left);

    result = entry->ReadArray(chroma_padding_weights_left, 8, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load dsx10_rgn_dataType_chroma_padding_weights_right_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool dsx10_rgn_dataType::chroma_padding_weights_right_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(chroma_padding_weights_right);

    result = entry->ReadArray(chroma_padding_weights_right, 8, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_dsx10_sr_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_dsx10_sr_scale_ratio_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(sr_scale_ratio_trigger);
    PARAMETER_INITIALIZE(dsx10_rgn_data);

    result = sr_scale_ratio_trigger.Load(entry, alignment);
    if (result)
    {
        result = dsx10_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_dsx10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_dsx10_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_dsx10_sr_scale_ratio_data);


    // Reading Array mod_dsx10_sr_scale_ratio_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_dsx10_sr_scale_ratio_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_dsx10_sr_scale_ratio_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_dsx10_sr_scale_ratio_dataID = pointerEntry->ID;
            DupObjInfo* mod_dsx10_sr_scale_ratio_dataDupInfo = pointerEntry->GetDupObject(mod_dsx10_sr_scale_ratio_dataCount, file, line);
            if (mod_dsx10_sr_scale_ratio_dataDupInfo != nullptr && mod_dsx10_sr_scale_ratio_dataDupInfo->Object != nullptr)
            {
                mod_dsx10_sr_scale_ratio_data = (mod_dsx10_sr_scale_ratio_dataType*)mod_dsx10_sr_scale_ratio_dataDupInfo->Object;
                if (mod_dsx10_sr_scale_ratio_data == nullptr)
                {
                    if (mod_dsx10_sr_scale_ratio_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_dsx10_sr_scale_ratio_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_dsx10_sr_scale_ratio_dataDupInfo->File, mod_dsx10_sr_scale_ratio_dataDupInfo->Line, mod_dsx10_sr_scale_ratio_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_dsx10_sr_scale_ratio_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_dsx10_sr_scale_ratio_dataDupInfo->Line, mod_dsx10_sr_scale_ratio_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_dsx10_sr_scale_ratio_data == nullptr)
            {
                if (result && mod_dsx10_sr_scale_ratio_dataCount > 0)
                {
                    mod_dsx10_sr_scale_ratio_data = PARAMETER_NEW mod_dsx10_sr_scale_ratio_dataType[mod_dsx10_sr_scale_ratio_dataCount];
                    (void)pointerEntry->SetDupObject(mod_dsx10_sr_scale_ratio_data, mod_dsx10_sr_scale_ratio_dataCount, file, line);
                }
                if (!result || mod_dsx10_sr_scale_ratio_data == nullptr)
                {
                    if (mod_dsx10_sr_scale_ratio_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_dsx10_sr_scale_ratio_data\n");
                    }
                    mod_dsx10_sr_scale_ratio_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_dsx10_sr_scale_ratio_dataCount; i++)
                {
                    result = mod_dsx10_sr_scale_ratio_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_dsx10_sr_scale_ratio_data == nullptr)
        {
            mod_dsx10_sr_scale_ratio_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_dsx10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_dsx10Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(chromatix_dsx10_reserve);
    PARAMETER_INITIALIZE(chromatix_dsx10_core);

    result = module_version.Load(entry, alignment);
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_dsx10_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_dsx10_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_dsx10Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_dsx10Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_dsx10Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    result = chromatix_dsx10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_dsx10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_dsx10_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_dsx10_sr_scale_ratio_data))
    {
        PARAMETER_DELETE[] mod_dsx10_sr_scale_ratio_data;
    }
    mod_dsx10_sr_scale_ratio_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_dsx10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_dsx10Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_dsx10_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_dsx10Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_dsx10Type::Release()
{
    ((chromatix_dsx10TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_dsx10Type::GetModified()
{
    return ((chromatix_dsx10TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_dsx10TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_dsx10TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_dsx10TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_dsx10TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_dsx10TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_dsx10TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_dsx10TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_dsx10TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_dsx10TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_dsx10TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_dsx10TypeClass::Release()
{
    ParameterModule::Release();
}

DSX_1_0_0_NAMESPACE_END
